@@ -34,7 +34,7 @@ Usage::
     describe_orderable_db_instance_options_paginator: DescribeOrderableDBInstanceOptionsPaginator = client.get_paginator("describe_orderable_db_instance_options")
     ```
 """
-from mypy_boto3_docdb.client import DocDBClient, DocDBClient as Client
+from mypy_boto3_docdb.client import DocDBClient
 from mypy_boto3_docdb.paginator import (
     DescribeDBClustersPaginator,
     DescribeDBEngineVersionsPaginator,
@@ -45,6 +45,8 @@ from mypy_boto3_docdb.paginator import (
 )
 from mypy_boto3_docdb.waiter import DBInstanceAvailableWaiter, DBInstanceDeletedWaiter
 
+Client = DocDBClient
+
 
 __all__ = (
     "Client",
